@@ -14,8 +14,6 @@ sub entry_point($self) {
         $self->cmd_help();
     }
     $self->check_privileges();
-    # would be very nice if we can set a type hint here...possible?
-    $self->{'wg_meta'} = Wireguard::WGmeta::Wrapper::Config->new($self->{wireguard_home});
     $self->_run_command();
 }
 
@@ -23,17 +21,15 @@ sub entry_point($self) {
 sub _run_command($self){
     my $interface = $self->_retrieve_or_die($self->{input_args}, 0);
     my $identifier = $self->_retrieve_or_die($self->{input_args}, 1);
-    eval {
-        $identifier = $self->{wg_meta}->translate_alias($interface, $identifier);
-    };
-    $self->{wg_meta}->enable($interface, $identifier);
+    $identifier = $self->wg_meta->try_translate_alias($interface, $identifier);
+    $self->wg_meta->enable($interface, $identifier);
 
     if (defined $ENV{IS_TESTING}) {
         # omit header
-        $self->{wg_meta}->commit(1, 1);
+        $self->wg_meta->commit(1, 1);
     }
     else {
-        $self->{wg_meta}->commit(1, 0);
+        $self->wg_meta->commit(1, 0);
     }
 }
 
